function t = mttistril(x)
%MTTISTRIL True for lower triangular matrices.
%
%   MTTISTRIL(X) returns 1 if X is an lower triangular matrix, and 0
%   otherwise.
%
%   This function is essentially the same as using
%
%      isequal(X, tril(X))
%
%   but MTTISTRIL requires less memory.
%
%   See also TRIL.

%   This program is a part of the MTT (MATLAB Tips & Tricks) Toolbox.
%   Copyright (c) 2002 Peter J. Acklam. All rights reserved.
%
%   This program is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.  See the file COPYING for details.
%
%   Author:      Peter J. Acklam
%   Time-stamp:  2003-03-31 18:31:41 +0200
%   E-mail:      pjacklam@online.no
%   URL:         http://home.online.no/~pjacklam

   error(nargchk(1, 1, nargin));

   if ndims(x) ~= 2
      error('Input must be a 2-D array (matrix).');
   end

   t = 1;

   n = size(x, 2);
   for j = 1 : n
      k = find(x(:,j));
      if ~isempty(k) & (k(1) < j)
         t = 0;
         return
      end
   end
