function t = mttistriu(x)
%MTTISTRIU True for upper triangular matrices.
%
%   MTTISTRIU(X) returns 1 if X is an upper triangular matrix, and 0
%   otherwise.
%
%   This function is essentially the same as using
%
%      isequal(X, triu(X))
%
%   but MTTISTRIU requires less memory.
%
%   See also TRIU.

%   This program is a part of the MTT (MATLAB Tips & Tricks) Toolbox.
%   Copyright (c) 2002 Peter J. Acklam. All rights reserved.
%
%   This program is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.  See the file COPYING for details.
%
%   Author:      Peter J. Acklam
%   Time-stamp:  2003-03-31 18:31:38 +0200
%   E-mail:      pjacklam@online.no
%   URL:         http://home.online.no/~pjacklam

   error(nargchk(1, 1, nargin));

   if ndims(x) ~= 2
      error('Input must be a 2-D array (matrix).');
   end

   t = 1;

   n = size(x, 1);
   for i = 1 : n
      k = find(x(i,:));
      if ~isempty(k) & (k(1) < i)
         t = 0;
         return
      end
   end
