function [y, c] = mttmode(x)
%MTTMODE Statistical mode.
%
%   M = MTTMODE(X) returns the mode, or modes, of the vector X.
%   [M, COUNT] = MODE(X) also returns how many times the mode appears in X.

%   This program is a part of the MTT (MATLAB Tips & Tricks) Toolbox.
%   Copyright (c) 2002 Peter J. Acklam. All rights reserved.
%
%   This program is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.  See the file COPYING for details.
%
%   Author:      Peter J. Acklam
%   Time-stamp:  2003-03-31 18:31:35 +0200
%   E-mail:      pjacklam@online.no
%   URL:         http://home.online.no/~pjacklam

   % check number of input arguments
   error(nargchk(1, 1, nargin));

   x = sort(x);
   [len, val] = mttrlencode(x);

   count = max(len);                    % longest run
   pos = find(len == count);            % find all runs with this length
   m = val(pos);                        % pick corresponding values(s)
