function siz = mttsize(x, dims)
%MTTSIZE  Sizes of a matrix or array.
%
%   S = MTTSIZE(X, DIMS), returns a vector with the sizes of X along the
%   dimensions specified in DIMS.  That is, S(I) = SIZE(X, DIMS(I)) for all
%   I = 1...LENGTH(DIMS).
%
%   See also SIZE, LENGTH, NDIMS, NUMEL.

%   This program is a part of the MTT (MATLAB Tips & Tricks) Toolbox.
%   Copyright (c) 2002 Peter J. Acklam. All rights reserved.
%
%   This program is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.  See the file COPYING for details.
%
%   Author:      Peter J. Acklam
%   Time-stamp:  2003-03-31 18:31:01 +0200
%   E-mail:      pjacklam@online.no
%   URL:         http://home.online.no/~pjacklam

   % check number of input arguments
   nargsin = nargin;
   error(nargchk(1, 2, nargsin));

   sd = size(dims);
   if sum(size(dims) > 1) > 1 | any(dims < 1)
      error('DIMS must be a vector of positive integers.');
   end
   dims = fix(dims);         % make sure values are integers

   sx = size(x);
   dx = ndims(x);

   k = dims <= dx;
   siz = ones(sd);
   siz(k) = sx(dims(k));
